require 'spec_helper'

describe ServState::UsageManager do
  let(:manager) { described_class.new }

  context 'interfaces' do

    it 'should return hash' do
      expect(manager.interfaces).to be_a Hash
    end

    it 'hash should contain at least lo interface' do
      expect(manager.interfaces.keys).to include 'lo'
    end

    it 'lo interface should has ip' do
      expect(manager.interfaces['lo']).to eq('127.0.0.1')
    end
  end

  context 'uptime' do

    it 'should return hash' do
      expect(manager.uptime).to be_a Hash
    end

    context 'should has right' do
      let(:upt) { manager.uptime }

      it 'total_sec value' do
        expect(upt[:total_sec]).to be > 0
      end

      it 'days value' do
        expect(upt[:days]).to be >= 0
      end

      it 'hours value' do
        expect(upt[:hours]).to be_between(0, 23)
      end

      it 'minutes value' do
        expect(upt[:minutes]).to be_between(0, 59)
      end

      it 'seconds value' do
        expect(upt[:seconds]).to be_between(0, 59)
      end

    end
  end

  context 'disk_usage' do
    let(:hash) { manager.disk_usage }

    it 'should has right types of values' do

      hash.each do |key, value|

        expect(key).to be_a String
        expect(value.size).to eq(5)
        expect(value[4]).to be_a String
        expect(value[0]).to be_between(0, 100)

      end
    end

    it 'should has total as sum of used and available' do
      hash.each do |key, value|
        expect(value[1]).to be >= value[2] + value[3]
      end
    end
  end

  context 'ram usage' do
    let(:hash) { manager.ram_usage }

    it 'should has right values types' do
      expect(hash[:ram].size).to eq(2)
      expect(hash[:swap].size).to eq(2)

      expect(hash[:ram_per]).to be_between(0, 100)
      expect(hash[:swap_per]).to be_between(0, 100)
    end

    it 'should has right values' do
      ram_values = hash[:ram]
      expect(ram_values[1]).to be < ram_values[0]

      swap_values = hash[:swap]
      expect(swap_values[1]).to be < swap_values[0]
    end

  end
end